.. rehome documentation master file, created by
   sphinx-quickstart.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

rehome: Rehome your Python scripts into nice interconnected modules
===================================================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    api


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
